@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
+import copy
 import os
 import warnings
 
@@ -180,14 +181,6 @@ def _cdf2df_3d_psp(cdf, index_key, dtimeindex=True, ignore=None, include=None):
     return return_df
 
 
-def psp_load(dataset, startdate, enddate, epilo_channel='F', epilo_threshold=None, path=None, resample=None):
-    """
-    Wrapper function for psp_isois_load() that pipes everything directly through.
-    """
-    df, energies_dict = psp_isois_load(dataset, startdate, enddate, epilo_channel, epilo_threshold, path, resample)
-    return df, energies_dict
-
-
 def psp_isois_load(dataset, startdate, enddate, epilo_channel='F', epilo_threshold=None, path=None, resample=None):
     """
     Downloads CDF files via SunPy/Fido from CDAWeb for CELIAS, EPHIN, ERNE onboard SOHO
@@ -395,13 +388,11 @@ def calc_av_en_flux_PSP_EPIHI(df, energies, en_channel, species, instrument, vie
         if species.lower() in ['p', 'protons', 'i', 'ions', 'h']:
             species_str = 'H'
             flux_key = 'H_Flux'
+    en_str = energies[f'{species_str}_ENERGY_LABL']
     if type(en_channel) == list:
-        en_str = energies[f'{species_str}_ENERGY_LABL']
         energy_low = en_str[en_channel[0]][0].split('-')[0]
         energy_up = en_str[en_channel[-1]][0].split('-')[-1]
         en_channel_string = energy_low + '-' + energy_up
-        # replace multiple whitespaces with single ones
-        en_channel_string = ' '.join(en_channel_string.split())
 
         DE = energies[f'{species_str}_ENERGY_DELTAPLUS']+energies[f'{species_str}_ENERGY_DELTAMINUS']
 
@@ -424,7 +415,9 @@ def calc_av_en_flux_PSP_EPIHI(df, energies, en_channel, species, instrument, vie
             flux_out = pd.DataFrame({'flux': df[f'{viewing.upper()}_{flux_key}_{en_channel}']}, index=df.index)
     else:
         flux_out = pd.DataFrame({'flux': df[f'{viewing.upper()}_{flux_key}_{en_channel}']}, index=df.index)
-        en_channel_string = en_str[en_channel]
+        en_channel_string = en_str[en_channel][0]
+    # replace multiple whitespaces with single ones
+    en_channel_string = ' '.join(en_channel_string.split())
     return flux_out, en_channel_string
 
 
@@ -505,3 +498,6 @@ def calc_av_en_flux_PSP_EPILO(df, en_dict, en_channel, species, mode, chan, view
                 en_channel = en_channel[0]
                 flux_out = pd.DataFrame({'flux': df[f"{flux_key}_Chan{chan}_E{en_channel}_P{viewing}"]}, index=df.index)
     return flux_out, en_channel_string
+
+
+psp_load = copy.copy(psp_isois_load)
