@@ -204,6 +204,7 @@ def stereo_sept_loader(startdate, enddate, spacecraft, species, viewing, resampl
         # replace bad data with np.nan:
         df = df.replace(-9999.900, np.nan)
 
+        # TODO: (as it's not really nicely done so far)
         # careful!
         # adjusting the position of the timestamp manually.
         # requires knowledge of the original time resolution and timestamp position!
@@ -318,6 +319,8 @@ def stereo_load(instrument, startdate, enddate, spacecraft='ahead', mag_coord='R
         - 'MAGB': STEREO IMPACT/MAG Burst Mode (~0.03 sec) Magnetic Field Vectors (RTN or SC => mag_coord)
             https://cdaweb.gsfc.nasa.gov/misc/NotesS.html#STA_L1_MAGB_RTN
             https://cdaweb.gsfc.nasa.gov/misc/NotesS.html#STA_L1_MAGB_SC
+       - 'MAGPLASMA': STEREO IMPACT/MAG Magnetic Field and PLASTIC Solar Wind Plasma Level 2 Data
+            https://cdaweb.gsfc.nasa.gov/misc/NotesS.html#STA_L2_MAGPLASMA_1M
         - 'SEPT': STEREO IMPACT/SEPT Level 2 Data
     startdate, enddate : {datetime or str}
         Datetime object (e.g., dt.date(2021,12,31) or dt.datetime(2021,4,15)) or "standard"
@@ -347,8 +350,9 @@ def stereo_load(instrument, startdate, enddate, spacecraft='ahead', mag_coord='R
     metadata : {dict}
         Dictionary containing different metadata, e.g., energy channels
     """
-    if startdate==enddate:
-        print(f'"startdate" and "enddate" must be different!')
+    trange = a.Time(startdate, enddate)
+    if trange.min==trange.max:
+        print(f'"startdate" and "enddate" might need to be different!')
     if not (pos_timestamp=='center' or pos_timestamp=='start' or pos_timestamp is None):
         raise ValueError(f'"pos_timestamp" must be either None, "center", or "start"!')
 
@@ -374,12 +378,15 @@ def stereo_load(instrument, startdate, enddate, spacecraft='ahead', mag_coord='R
         sc = 'ST' + spacecraft.upper()[0]
 
         # define dataset
-        if instrument.upper()[:3]=='MAG':
+        if (instrument.upper()[:3]=='MAG') & (instrument.upper()!='MAGPLASMA'):
             dataset = sc + '_L1_' + instrument.upper() + '_' + mag_coord.upper()
+        elif instrument.upper()=='MAGPLASMA':
+            dataset = sc + '_L2_MAGPLASMA_1M'
+        # elif instrument.upper()[:3]=='PLA':
+        #     dataset = sc + '_L2_PLA_1DMAX_1MIN'
         else:
             dataset = sc + '_L1_' + instrument.upper()
 
-        trange = a.Time(startdate, enddate)
         cda_dataset = a.cdaweb.Dataset(dataset)
         try:
             result = Fido.search(trange, cda_dataset)
@@ -403,8 +410,8 @@ def stereo_load(instrument, startdate, enddate, spacecraft='ahead', mag_coord='R
 
             metadata = _get_metadata(dataset, downloaded_files[0])
 
-            # remove this (i.e. following two lines) when sunpy's read_cdf is updated,
-            # and FILLVAL will be replaced directly, see
+            # TODO: remove this (i.e. following two lines) when sunpy's
+            # read_cdf is updated, and FILLVAL will be replaced directly, see
             # https://github.com/sunpy/sunpy/issues/5908
             if instrument.upper() == 'HET':
                 df = df.replace(metadata['Electron_Flux_FILLVAL'], np.nan)
@@ -413,7 +420,17 @@ def stereo_load(instrument, startdate, enddate, spacecraft='ahead', mag_coord='R
                 df = df.replace(-2147483648, np.nan)
             if instrument.upper() == 'MAG':
                 df = df.replace(-1e+31, np.nan)
+            if instrument.upper() == 'MAGPLASMA':
+                df = df.replace(-1.0e+30, np.nan)
 
+            # Because MAGPLASMA datafiles are for full calendar years, select only
+            # the requested time range from it. Using trange because startdate
+            # or enddate can be strings.
+            if instrument.upper() == 'MAGPLASMA':
+                # df = df[(df.index>=trange.min.value) & (df.index < (trange.max+pd.Timedelta('1d')).value)]
+                df = df[(df.index>=trange.min.value) & (df.index < trange.max.value)]
+
+            # TODO: (as it's not really nicely done so far)
             # careful!
             # adjusting the position of the timestamp manually.
             # requires knowledge of the original time resolution and timestamp position!
@@ -423,7 +440,9 @@ def stereo_load(instrument, startdate, enddate, spacecraft='ahead', mag_coord='R
             if pos_timestamp == 'start':
                 if instrument.upper() == 'LET':
                     df.index = df.index-pd.Timedelta('30s')
-
+                if instrument.upper() == 'MAGPLASMA':
+                    df.index = df.index-pd.Timedelta('30s')
+            
             if isinstance(resample, str):
                 df = resample_df(df, resample, pos_timestamp=pos_timestamp)
         except RuntimeError:
